@@ -20,7 +20,7 @@ package MongoDB::Op::_BulkWrite;
 # MongoDB::BulkWriteResult object
 
 use version;
-our $VERSION = 'v2.0.2';
+our $VERSION = 'v2.2.1';
 
 use Moo;
 
@@ -40,7 +40,6 @@ use Types::Standard qw(
     InstanceOf
 );
 use Safe::Isa;
-use Try::Tiny;
 use boolean;
 
 use namespace::clean;
@@ -80,7 +79,7 @@ with $_ for qw(
 
 sub _is_retryable {
     my $self = shift;
-    return $self->write_concern->is_acknowledged && $self->_retryable;
+    return $self->_should_use_acknowledged_write && $self->_retryable;
 }
 
 sub has_collation {
@@ -103,7 +102,7 @@ sub execute {
 
         MongoDB::UsageError->throw(
             "Unacknowledged bulk writes that specify a collation are not allowed")
-          if !$self->write_concern->is_acknowledged;
+          if !$self->_should_use_acknowledged_write;
     }
 
     my $use_write_cmd = $link->supports_write_commands;
@@ -145,7 +144,7 @@ sub execute {
     return MongoDB::UnacknowledgedResult->_new(
         write_errors         => [],
         write_concern_errors => [],
-    ) if !$self->write_concern->is_acknowledged;
+    ) if ! $self->_should_use_acknowledged_write;
 
     # only reach here with an error for unordered bulk ops
     $result->assert_no_write_error;
@@ -168,7 +167,7 @@ my %OP_MAP = (
 sub _execute_write_command_batch {
     my ( $self, $link, $batch, $result ) = @_;
 
-    my ( $type, $docs )   = @$batch;
+    my ( $type, $docs, $idx_map )   = @$batch;
     my ( $cmd,  $op_key ) = @{ $OP_MAP{$type} };
 
     my $boolean_ordered = boolean( $self->ordered );
@@ -176,12 +175,14 @@ sub _execute_write_command_batch {
       map { $self->$_ } qw/db_name coll_name write_concern/;
 
     my @left_to_send = ($docs);
+    my @sending_idx_map = ($idx_map);
 
     my $max_bson_size = $link->max_bson_object_size;
     my $supports_document_validation = $link->supports_document_validation;
 
     while (@left_to_send) {
         my $chunk = shift @left_to_send;
+        my $chunk_idx_map = shift @sending_idx_map;
         # for update/insert, pre-encode docs as they need custom BSON handling
         # that can't be applied to an entire write command at once
         if ( $cmd eq 'update' ) {
@@ -231,8 +232,8 @@ sub _execute_write_command_batch {
             $self->_is_retryable
               ? $self->client->send_retryable_write_op( $op )
               : $self->client->send_write_op( $op );
-        };
-        if ( my $error = $@ ) {
+        } or do {
+            my $error = $@ || "Unknown error";
             # This error never touches the database!.... so is before any retryable writes errors etc.
             if ( $error->$_isa("MongoDB::_CommandSizeError") ) {
                 if ( @$chunk == 1 ) {
@@ -243,6 +244,7 @@ sub _execute_write_command_batch {
                 }
                 else {
                     unshift @left_to_send, $self->_split_chunk( $chunk, $error->size );
+                    unshift @sending_idx_map, $self->_split_chunk( $chunk_idx_map, $error->size );
                 }
             }
             elsif ( $error->$_can( 'result' ) ) {
@@ -251,10 +253,11 @@ sub _execute_write_command_batch {
                 # check for write errors, as they have a higher priority than
                 # write concern errors.
                 MongoDB::BulkWriteResult->_parse_cmd_result(
-                    op => $type,
+                    op       => $type,
                     op_count => scalar @$chunk,
-                    result => $error->result,
-                    cmd_doc => $cmd_doc,
+                    result   => $error->result,
+                    cmd_doc  => $cmd_doc,
+                    idx_map  => $chunk_idx_map,
                 )->assert_no_write_error;
                 # Explode with original error
                 die $error;
@@ -262,7 +265,7 @@ sub _execute_write_command_batch {
             else {
                 die $error;
             }
-        }
+        };
 
         redo unless $cmd_result; # restart after a chunk split
 
@@ -271,6 +274,7 @@ sub _execute_write_command_batch {
             op_count => scalar @$chunk,
             result   => $cmd_result,
             cmd_doc  => $cmd_doc,
+            idx_map  => $chunk_idx_map,
         );
 
         # append corresponding ops to errors
@@ -309,17 +313,20 @@ sub _batch_ordered {
 
     my $max_batch_count = $link->max_write_batch_size;
 
+    my $queue_idx = 0;
     for my $op (@$queue) {
         my ( $type, $doc ) = @$op;
         if ( $type ne $last_type || $count == $max_batch_count ) {
-            push @batches, [ $type => [$doc] ];
+            push @batches, [ $type => [$doc], [$queue_idx] ];
             $last_type = $type;
             $count     = 1;
         }
         else {
-            push @{ $batches[-1][-1] }, $doc;
+            push @{ $batches[-1][1] }, $doc;
+            push @{ $batches[-1][2] }, $queue_idx;
             $count++;
         }
+        $queue_idx++;
     }
 
     return @batches;
@@ -327,24 +334,33 @@ sub _batch_ordered {
 
 sub _batch_unordered {
     my ( $self, $link, $queue ) = @_;
-    my %batches = map { ; $_ => [ [] ] } keys %OP_MAP;
+    my %batches = map { $_ => [ [] ] } keys %OP_MAP;
+    my %queue_map = map { $_ => [ [] ] } keys %OP_MAP;
 
     my $max_batch_count = $link->max_write_batch_size;
 
+    my $queue_idx = 0;
     for my $op (@$queue) {
         my ( $type, $doc ) = @$op;
         if ( @{ $batches{$type}[-1] } == $max_batch_count ) {
             push @{ $batches{$type} }, [$doc];
+            push @{ $queue_map{$type} }, [ $queue_idx ];
         }
         else {
             push @{ $batches{$type}[-1] }, $doc;
+            push @{ $queue_map{$type}[-1] }, $queue_idx;
         }
+        $queue_idx++;
     }
 
     # insert/update/delete are guaranteed to be in random order on Perl 5.18+
     my @batches;
     for my $type ( grep { scalar @{ $batches{$_}[-1] } } keys %batches ) {
-        push @batches, map { [ $type => $_ ] } @{ $batches{$type} };
+        push @batches, map { [
+            $type,
+            $batches{$type}[$_],
+            $queue_map{$type}[$_], # array of indices from the original queue
+        ] } 0 .. $#{ $batches{$type} };
     }
     return @batches;
 }
@@ -413,16 +429,16 @@ sub _execute_legacy_batch {
             );
         }
 
-        my $op_result = try {
+        my $op_result = eval {
             $op->execute($link);
-        }
-        catch {
-            if (   $_->$_isa("MongoDB::DatabaseError")
-                && $_->result->does("MongoDB::Role::_WriteResult") )
+        } or do {
+            my $error = $@ || "Unknown error";
+            if (   $error->$_isa("MongoDB::DatabaseError")
+                && $error->result->does("MongoDB::Role::_WriteResult") )
             {
-                return $_->result;
+                return $error->result;
             }
-            die $_ unless $w_0 && /exceeds maximum size/;
+            die $error unless $w_0 && /exceeds maximum size/;
             return undef; ## no critic: this makes op_result undef
         };
 
