@@ -21,7 +21,7 @@ package MongoDB::Role::_BypassValidation;
 # to a command
 
 use version;
-our $VERSION = 'v2.0.3';
+our $VERSION = 'v2.2.1';
 
 use Moo::Role;
 
@@ -41,8 +41,7 @@ has bypassDocumentValidation => (
 # flag, original command; returns (possibly modified) command
 sub _maybe_bypass {
     push @{ $_[2] },
-      bypassDocumentValidation => ( $_[0]->bypassDocumentValidation ? true : false )
-      if $_[1] && defined $_[0]->bypassDocumentValidation;
+      bypassDocumentValidation => true if $_[1] && $_[0]->bypassDocumentValidation;
     return $_[2];
 }
 
